==> v8.3.zip: ru_twords_ru_tw/bible/other/reward.md <==
# воздавать, воздаяние, награда, награждать

## Определение:

Слово “воздаяние” означает то, что человек получает за свои дела: хорошие или плохие. Слово “воздавать” означает “давать кому-либо то, что он заслуживает”.

* Воздаяние или награда — могут быть чем-то позитивным, что получает человек за сделанное им. В Библии воздаянием часто называют награду за послушание Богу.
* Воздаяние может быть также последствием плохих поступков. В таком случае это слово употребляется в значении “наказание”.

## Варианты перевода:

* В зависимости от контекста слово “воздаяние” может переводиться как “расплата”, “награда” или “наказание”.
* Слово “воздавать кому-либо” можно перевести как “награждать”, “наказывать”, “отплачивать” или “платить по заслугам”.
* Воздаяние не обязательно является наградой или заработком за выполненную работу. Поэтому проверьте, в каком контексте употребляется это слово.

(См. также: [наказывать](../other/punish.md))

## Ссылки на библейский текст:

* [Втор. 32:5-6](rc://*/tn/help/deu/32/05)
* [Ис. 40:9-10](rc://*/tn/help/isa/40/09)
* [Лк. 6:35-36](rc://*/tn/help/luk/06/35)
* [Мк. 9:40-41](rc://*/tn/help/mrk/09/40)
* [Мф. 5:11-12](rc://*/tn/help/mat/05/11)
* [Мф. 6:3-4](rc://*/tn/help/mat/06/03)
* [Пс. 127:3-5](rc://*/tn/help/psa/127/003)
* [Откр. 11:18](rc://*/tn/help/rev/11/18)

## Данные о слове:

* Номера Стронга: H319, H866, H868, H1576, H1578, H1580, H4864, H4909, H4991, H5023, H6118, H6468, H6529, H7809, H7810, H7936, H7938, H7939, H7966, H7999, H8011, H8021, G469, G514, G591, G2603, G3405, G3406, G3408

==> v9.2.zip: ru_twords_ru_tw/bible/other/reward.md <==
# воздавать, воздаяние, награда, награждать

## Определение:

Слово “воздаяние” означает то, что человек получает за свои дела: хорошие или плохие. Слово “воздавать” означает “давать кому-либо то, что он заслуживает”.
* Воздаяние или награда — могут быть чем-то позитивным, что получает человек за сделанное им. В Библии воздаянием часто называют награду за послушание Богу.
* Воздаяние может быть также последствием плохих поступков. В таком случае это слово употребляется в значении “наказание”.

## Варианты перевода:

* В зависимости от контекста слово “воздаяние” может переводиться как “расплата”, “награда” или “наказание”.
* Слово “воздавать кому-либо” можно перевести как “награждать”, “наказывать”, “отплачивать” или “платить по заслугам”.
* Воздаяние не обязательно является наградой или заработком за выполненную работу. Поэтому проверьте, в каком контексте употребляется это слово.

(См. также: [наказывать](../other/punish.md))

## Ссылки на библейский текст:

* [Втор. 32:5-6](rc://ru/tn/help/deu/32/05)
* [Ис. 40:9-10](rc://ru/tn/help/isa/40/09)
* [Лк. 6:35-36](rc://ru/tn/help/luk/06/35)
* [Мк. 9:40-41](rc://ru/tn/help/mrk/09/40)
* [Мф. 5:11-12](rc://ru/tn/help/mat/05/11)
* [Мф. 6:3-4](rc://ru/tn/help/mat/06/03)
* [Пс. 127:3-5](rc://ru/tn/help/psa/127/003)
* [Откр. 11:18](rc://ru/tn/help/rev/11/18)

## Данные о слове:

* Номера Стронга: H319, H866, H868, H1576, H1578, H1580, H4864, H4909, H4991, H5023, H6118, H6468, H6529, H7809, H7810, H7936, H7938, H7939, H7966, H7999, H8011, H8021, G469, G514, G591, G2603, G3405, G3406, G3408
